@@ -27,8 +27,10 @@ module TMail
     end
 
     def initialize( local, domain )
-      local.each do |s|
-        raise SyntaxError, 'empty word in local' if s.empty?
+      if local
+        local.each do |s|
+          raise SyntaxError, 'empty word in local' if s.empty?
+        end
       end
       if domain then
         domain.each do |s|
@@ -58,7 +60,7 @@ module TMail
     end
 
     def local
-      @local.collect {|i| quote_atom(i) }.join('.')
+      @local and @local.map {|i| quote_atom(i) }.join('.')
     end
 
     def domain
@@ -66,8 +68,9 @@ module TMail
     end
 
     def spec
-      s = local()
-      if d = domain() then
+      s = self.local
+      d = self.domain
+      if s and d
         s << '@' << d
       end
       s
@@ -97,17 +100,21 @@ module TMail
     include StrategyInterface
 
     def accept( strategy, dummy = nil )
-      spec_p = (not @name and @routes.empty?)
+      unless @local
+        strategy.meta '<>'   # empty return-path
+        return
+      end
 
+      spec_p = (not @name and @routes.empty?)
       if @name then
         strategy.phrase @name
         strategy.space
       end
       tmp = spec_p ? '' : '<'
       unless @routes.empty? then
-        tmp << @routes.collect {|i| '@' + i }.join(',') << ':'
+        tmp << @routes.map {|i| '@' + i }.join(',') << ':'
       end
-      tmp << address
+      tmp << self.spec
       tmp << '>' unless spec_p
       strategy.meta tmp
       strategy.lwsp ''
@@ -139,7 +146,7 @@ module TMail
     alias eql? ==
 
     def hash
-      collect {|i| i.hash }.hash
+      map {|i| i.hash }.hash
     end
 
     def []( idx )
